# sslinfo

sslinfo is a small uility (developed in Python) to print the SSL certificate info for a remote service

Expected to work on Windows, Linux and Mac .

## Motivation

Needed a quick way to verify remote TLS certificates


## Requirements
- Python3

## How to install
```sh
pip instal sslinfo
```

## How to use
```sh
sslinfo www.sapo.pt
```
